@@ -6,9 +6,9 @@ import io
 import numpy as np
 # from release_test.CAD_Recognition.data_load import  load_data, _load_data, _data_normalization, data_normalization, _k_folds
 # from release_test.CAD_Recognition.features import dataset_getmfcc
-from release.CAD_Recognition.data_load import (load_data, load_data_, data_normalization_, data_normalization, k_folds_, extract_name)
-from release.CAD_Recognition.features import dataset_getmfcc
-from release.CAD_Recognition.devide_no_test import data_transform
+from CAD_Recognition.data_load import (load_data, load_data_, data_normalization_, data_normalization, k_folds_, extract_name)
+from CAD_Recognition.features import dataset_getmfcc
+from CAD_Recognition.devide_no_test import data_transform
 import os
 import tensorflow as tf
 from keras import backend as KTF
